# Critical SQL Injection flaws in Gentoo Soko can lead to Remote Code Execution
## SQL injection vulnerabilities in Gentoo Soko could lead to remote code execution (RCE) on impacted systems. SonarSource researchers discovered two SQL injection vulnerabilities in Gentoo Soko, collectively tracked as CVE-2023-28424 (CVSS score: 9.1) [1],[2], that can be exploited by a remote attacker to execute arbitrary code on vulnerable systems. “The two package search handlers, Search […]
## Information:

+ Link: https://securityaffairs.com/147911/hacking/gentoo-soko-sqli.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 28 June 2023, 12:31
+ Date scraped: 28 June 2023, 14:10

## Article:
![Main article image](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2012/10/SQLInjection.jpg?resize=300%2C300&ssl=1)


## SQL injection vulnerabilities in Gentoo Soko could lead to remote code execution (RCE) on impacted systems.


SonarSource researchers discovered two SQL injection vulnerabilities in Gentoo Soko, collectively tracked as CVE-2023-28424 (CVSS score: 9.1) [[1](https://github.com/gentoo/soko/security/advisories/GHSA-45jr-w89p-c843)],[[2](https://github.com/gentoo/soko/security/advisories/GHSA-gc2x-86p3-mxg2)], that can be exploited by a remote attacker to execute arbitrary code on vulnerable systems.


*“The two package search handlers, Search and SearchFeed, implemented in pkg/app/handler/packages/search.go, are affected by a SQL injection via the q parameter. As a result, unauthenticated attackers can execute arbitrary SQL queries on https://packages.gentoo.org/.” reads the [advisory](https://github.com/gentoo/soko/security/advisories/GHSA-gc2x-86p3-mxg2) published on GitHub. “It was also demonstrated that primitive was enough to gain code execution in the context of the PostgreSQL container.”* 


  ![](//assets.vlitag.com/widget/2023/03/24/1679645040.png) .vi\_svg{cursor:pointer;width:38px!important;height:38px!important;display:none;margin:0!important;max-width:initial!important}.vislider\_\_control\_\_bottom .progress{position:relative;bottom:35px;left:0;height:5px!important;transition:height .3s;background:rgba(0,0,0,.5);cursor:pointer;flex:none;-ms-flex:none;display:flex;width:100%;margin:0;border-radius:0;box-shadow:none}.vislider\_\_control\_\_bottom .progress .progress\_\_filled{width:0%;background:#ddd;-ms-flex:0;flex:0;-ms-flex-preferred-size:0;flex-basis:0%}.vislider\_\_control\_\_bottom button{float:right;max-height:20px}.vislider\_\_control\_\_bottom .vi\_\_time{color:#ddd;margin-left:5px;line-height:1;font-size:13px;display:inline-block}.vi\_slider\_control\_custom{font-family:"Helvetica Neue","Calibri Light",Roboto,sans-serif;letter-spacing:.02em}.vi\_\_player.vi\_\_played:hover .opacity\_\_control{visibility:visible;opacity:1}.playerWrapper button{background:no-repeat;border:none;outline:0;padding:0;display:inline-block;cursor:pointer;font-size:14px!important;background-color:transparent!important}.vi\_slider\_control\_custom .vislider\_\_control\_\_middle{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.vi\_slider\_control\_custom .vislider\_\_control\_\_middle .vi\_\_middle\_button{display:-ms-flexbox;display:flex;justify-content:center;-ms-flex-align:center;align-items:center;justify-content:center;align-items:center;position:absolute;top:50%;left:50%;-ms-transform:translate(-50%,-50%) scale(1);transform:translate(-50%,-50%) scale(1)}.vi\_slider\_control\_custom .vislider\_\_control\_\_middle .vi\_\_button{width:15px!important;height:15px!important;margin:0 30px}.vi\_\_loading .vislider\_\_control\_\_middle .vi\_\_middle\_button{display:none}.slider\_\_control{position:absolute;bottom:0;left:0;width:100%;height:auto!important}.opacity\_\_control{visibility:hidden;opacity:0}.vi\_\_player:not(.vi\_\_played) .vi\_\_button,.vi\_\_player:not(.vi\_\_played) .vislider\_\_control\_\_bottom{display:none}.slider\_\_control#vislider\_control\_overlay{position:absolute;top:0;bottom:0;left:0;right:0;background-color:rgba(0,0,0,.2);cursor:pointer}.vislider\_\_loading{display:none;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.vi\_\_loading .vislider\_\_loading{display:block}#vi\_svg\_play{display:block}#btn\_control\_player{cursor:pointer;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);padding:9px;border-radius:50%;display:block;width:auto;height:auto;margin:0;max-width:inherit}.vi\_\_player:not(.vi\_\_played) #btn\_control\_player{opacity:1;visibility:visible}.vi\_\_player.vi\_\_paused .opacity\_\_control{visibility:visible;opacity:1}#vi\_toggleVolVideo .vi\_\_mutedVideo,#vi\_toggleVolVideo .vi\_\_volVideo{padding:initial;background-color:transparent;display:block;height:19px;box-sizing:content-box;position:relative;top:0;right:0}#vi\_toggleVolVideo .icon-volume{position:absolute;top:0;right:0}.sound\_on .vi\_\_mutedVideo{display:none!important}.sound\_off .vi\_\_volVideo{display:none!important}#hide\_fullscreen\_slider{position:absolute;display:none;top:-25px;right:-25px;cursor:pointer}#vi\_poster\_\_video{position:absolute;top:0;left:0;width:inherit!important;height:inherit!important;visibility:hidden;opacity:0}.adWrapperBox .adWrapper video{height:100%!important}.vislider\_\_control\_\_bottom .vi\_slider\_\_button{margin:0 5px;width:14px;height:14px}@media only screen and (max-width:480px){#hide\_fullscreen\_slider{top:-30px;right:0}}                                                             00:00/00:00                                         

*“The GraphiQL resolver PackageSearch, implemented in pkg/api/graphql/resolvers/resolver.go, is affected by a SQL injection via the searchTerm parameter. As a result, unauthenticated attackers can execute arbitrary SQL queries on https://packages.gentoo.org/.” [states the advisory](https://github.com/gentoo/soko/security/advisories/GHSA-45jr-w89p-c843). “It was also demonstrated that primitive was enough to gain code execution in the context of the PostgreSQL container.”*


Soko is a software deployed in the Gentoo Linux infrastructure, the researchers pointed out that is possible to exploit the issue to carry out SQL injection attacks despite the use of an Object-Relational Mapping (ORM) library and prepared statements.


The researchers explained that the exploitation of the vulnerabilities is possible due to a misconfiguration of the database.


The misconfiguration likely comes from the Docker containerization of their database, the experts pointed out that containers often “enjoy elevated privileges” because they are seen as a security boundary between software components.


SonarSource’s report states that a threat actor can inject specially crafted code to circumvent the escaping feature in the module to compose the queries and introduce SQL injections, resulting in the exposure of sensitive data.


The researchers recommend development teams of understanding how ORM APIs are designed to avoid the exploitation of similar vulnerabilities.


*“In general, a common source of vulnerabilities with ORMs happens when there is no reference to the query builder instance in the current context; such cases are usually methods made to avoid code duplication across queries. Developers are then more likely to craft parts of the query manually and introduce SQL injections.” [concludes](https://www.sonarsource.com/blog/why-orms-and-prepared-statements-cant-always-win/) the report. “Additionally, every ORM comes with its own take on API design, and it can be tricky to know about unsafe code patterns at first sight. This is where Go’s typing could come in handy at the cost of some flexibility by introducing compile-time safeguards, forcing developers to always separate instructions (the prepared statement) from data (the user’s input).”*


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking,** **Gentoo Soko**)




  


---


  




## Tags:
***CVE's***: CVE-2023-28424
***urls***: https://packages.gentoo.org/

### Autogenerated tags:
sql orm
